@@ -29,8 +29,6 @@ struct _GgvControlPrivate {
 	float zoom_level;
 	gboolean has_zoomable_frame;
 
-	gboolean pane_auto_jump;
-
 	GtkWidget *root;
 
 	GtkObject *zoom_adj;
@@ -52,7 +50,9 @@ static struct {
 } zoom_level_items[] = {
 	{ 1.0/4.0, "/commands/Zoom0104" },
 	{ 1.0/2.0, "/commands/Zoom0102" },
+	{ 3.0/4.0, "/commands/Zoom0304" },
 	{ 1.0/1.0, "/commands/Zoom0101" },
+	{ 3.0/2.0, "/commands/Zoom0302" },
 	{ 2.0/1.0, "/commands/Zoom0201" },
 	{ 4.0/1.0, "/commands/Zoom0401" },
 	{ 0.0, NULL }
@@ -60,16 +60,6 @@ static struct {
 
 static BonoboControlClass *ggv_control_parent_class;
 
-static void
-ggv_control_prefs_changed(GConfClient *client, guint cnxn_id,
-						  GConfEntry *entry, gpointer user_data)
-{
-	GgvControl *control = GGV_CONTROL(user_data);
-
-	if(!strcmp(entry->key, "/apps/ggv/control/autojump"))
-	   control->priv->pane_auto_jump = gconf_value_get_bool(entry->value);
-}
-
 static void
 ggv_control_destroy (BonoboObject *object)
 {
@@ -263,6 +253,7 @@ listener_ZoomLevel_cb(BonoboUIComponent *uic, const char *path,
 	BonoboZoomable *zoomable;
 	GgvControl *control;
 	const char *zl;
+	gint i;
 
 	g_return_if_fail(user_data != NULL);
 	g_return_if_fail(GGV_IS_CONTROL(user_data));
@@ -278,25 +269,12 @@ listener_ZoomLevel_cb(BonoboUIComponent *uic, const char *path,
 
 	zl = path + strlen("Zoom");
 
-	if(!strcmp(zl, "0104")) {
-		g_signal_emit_by_name (G_OBJECT (zoomable), "set_zoom_level",
-							   ((gfloat)1.0/4.0));
-	}
-	else if(!strcmp(zl, "0102")) {
-		g_signal_emit_by_name (G_OBJECT (zoomable), "set_zoom_level",
-							   ((gfloat)1.0/2.0));
-	}
-	else if(!strcmp(zl, "0101")) {
-		g_signal_emit_by_name (G_OBJECT (zoomable), "set_zoom_level",
-							   ((gfloat)1.0));
-	}
-	else if(!strcmp(zl, "0201")) {
-		g_signal_emit_by_name (G_OBJECT (zoomable), "set_zoom_level",
-							   ((gfloat)2.0/1.0));
-	}
-	else if(!strcmp(zl, "0401")) {
-		g_signal_emit_by_name (G_OBJECT (zoomable), "set_zoom_level",
-							   ((gfloat)4.0/1.0));
+	for(i = 0; zoom_level_items[i].path != NULL; i++) {
+		if(strstr(zoom_level_items[i].path, zl) != NULL) {
+			g_signal_emit_by_name (G_OBJECT (zoomable), "set_zoom_level",
+								   (gfloat)zoom_level_items[i].level);
+			break;
+		}
 	}
 }
 
@@ -328,8 +306,6 @@ ggv_control_key_press_event(GtkWidget *widget, GdkEventKey *event,
 		switch (orientation) {
 		case GTK_GS_ORIENTATION_PORTRAIT:
 			if(!gtk_gs_scroll_step(gs, GTK_SCROLL_STEP_DOWN, TRUE)) {
-                                /* Since we are doing wrapping, go to top of the page */
-				gtk_gs_scroll_to_edge(gs, GTK_POS_BOTTOM,  GTK_POS_BOTTOM);
 				ggv_postscript_view_goto_page(ps_view, gtk_gs_get_current_page(gs) + 1);
 			}
 			break;
@@ -393,13 +369,9 @@ ggv_control_key_press_event(GtkWidget *widget, GdkEventKey *event,
 		break;
 	case GDK_Page_Up:
 		ggv_postscript_view_goto_page(ps_view, gtk_gs_get_current_page(gs) - 1);
-		if(control->priv->pane_auto_jump)
-			gtk_gs_scroll_to_edge(gs, GTK_POS_BOTTOM, GTK_POS_BOTTOM);
 		break;
 	case GDK_Page_Down:
 		ggv_postscript_view_goto_page(ps_view, gtk_gs_get_current_page(gs) + 1);
-		if(control->priv->pane_auto_jump)
-			gtk_gs_scroll_to_edge(gs, GTK_POS_TOP, GTK_POS_TOP);
 		break;
 	case GDK_plus:
 		g_signal_emit_by_name(G_OBJECT (control->priv->zoomable),
@@ -498,6 +470,7 @@ _set_zoom_items_sensitivity(GgvControl *control, BonoboUIComponent *uic, gboolea
 {
 	gchar *prop_val = sens?"1":"0";
 	Bonobo_UIContainer container;
+	gint i;
 
 	container = bonobo_ui_component_get_container (uic);
 	if (container == CORBA_OBJECT_NIL)
@@ -514,16 +487,10 @@ _set_zoom_items_sensitivity(GgvControl *control, BonoboUIComponent *uic, gboolea
 								 "sensitive", prop_val, NULL);
 	bonobo_ui_component_set_prop(uic, "/commands/ZoomToFitWidth",
 								 "sensitive", prop_val, NULL);
-	bonobo_ui_component_set_prop(uic, "/commands/Zoom0104",
-								 "sensitive", prop_val, NULL);
-	bonobo_ui_component_set_prop(uic, "/commands/Zoom0102",
-								 "sensitive", prop_val, NULL);
-	bonobo_ui_component_set_prop(uic, "/commands/Zoom0101",
-								 "sensitive", prop_val, NULL);
-	bonobo_ui_component_set_prop(uic, "/commands/Zoom0201",
-								 "sensitive", prop_val, NULL);
-	bonobo_ui_component_set_prop(uic, "/commands/Zoom0401",
-								 "sensitive", prop_val, NULL);
+	for(i = 0; zoom_level_items[i].path != NULL; i++) {
+		bonobo_ui_component_set_prop(uic, zoom_level_items[i].path,
+									 "sensitive", prop_val, NULL);
+	}
 	bonobo_ui_component_thaw(uic, NULL);
 }
 
@@ -561,6 +528,8 @@ static void
 ggv_control_create_ui (GgvControl *control)
 {
 	GgvControlClass *klass;
+	GdkPixbuf *pixbuf;
+	gchar *pixbuf_xml;
 	int i;
 
 	g_return_if_fail (control != NULL);
@@ -570,6 +539,17 @@ ggv_control_create_ui (GgvControl *control)
 
 	bonobo_ui_util_set_ui(control->priv->uic, NULL, "ggv-control-ui.xml",
 						  "GGV", NULL);
+	pixbuf = gdk_pixbuf_new_from_file(GNOMEICONDIR "/ggv/fitwidth.png", NULL);
+	if(pixbuf != NULL) {
+		pixbuf_xml = bonobo_ui_util_pixbuf_to_xml(pixbuf);
+		bonobo_ui_component_set_prop(control->priv->uic,
+									 "/commands/ZoomToFitWidth",
+									 "pixname", pixbuf_xml,
+									 NULL);
+		g_free(pixbuf_xml);
+		gdk_pixbuf_unref(pixbuf);
+	}
+								 
 	control->priv->popup_uic = bonobo_control_get_popup_ui_component(BONOBO_CONTROL(control));
 	bonobo_ui_util_set_ui(control->priv->popup_uic, NULL, "ggv-postscript-view-ui.xml", "GGV", NULL);
 	bonobo_ui_util_set_ui(control->priv->popup_uic, NULL, "ggv-control-ui.xml", "GGV", NULL);
@@ -837,15 +817,6 @@ ggv_control_construct (GgvControl *control, GgvPostScriptView *ps_view)
 	control->priv->uic =
 		bonobo_control_get_ui_component (BONOBO_CONTROL (control));
 
-	control->priv->pane_auto_jump = gconf_client_get_bool(gtk_gs_defaults_gconf_client(),
-														  "/apps/ggv/control/autojump",
-														  NULL);
-	control->priv->gconf_notify_id =
-		gconf_client_notify_add(gtk_gs_defaults_gconf_client(),
-								"/apps/ggv/control",
-								(GConfClientNotifyFunc)ggv_control_prefs_changed,
-								control, NULL, NULL);
-
 	return control;
 }
 
