@@ -9,7 +9,8 @@
 
 #include <config.h>
 
-#include "ggv-window.h"
+#include <math.h>
+
 #include "ggv-prefs.h"
 #include "ggvutils.h"
 #include "gsdefaults.h"
@@ -174,7 +175,7 @@ ggv_prefs_dialog_setup(GgvPrefsDialog *dlg)
                 gint opt = 0;
                 
                 for (i = 0; i <= ggv_max_zoom_levels; i++) {
-                        dist = fabs(ggv_zoom_levels[i] - zoom);
+                        dist = fabs((double)(ggv_zoom_levels[i] - zoom));
                         if(dist < mindist) {
                                 opt = i;
                                 mindist = dist;
@@ -273,6 +274,18 @@ ggv_prefs_dialog_show(GgvPrefsDialog *dlg)
         gtk_widget_show(GTK_WIDGET(dlg));
 }
 
+static gboolean
+ggv_prefs_escape_pressed(GtkAccelGroup *accel_group,
+                         GObject *acceleratable,
+                         guint keyval,
+                         GdkModifierType modifier,
+                         gpointer data)
+{
+        GgvPrefsDialog *dlg = GGV_PREFS_DIALOG(data);
+        gtk_widget_hide(GTK_WIDGET(dlg));
+        return TRUE;
+}
+
 GtkWidget *
 ggv_prefs_dialog_new()
 {
@@ -289,6 +302,8 @@ ggv_prefs_dialog_new()
         gint i;
         GtkGSPaperSize *papersizes = gtk_gs_defaults_get_paper_sizes();
         GSList *tbstyle_group = NULL;
+        GtkAccelGroup *dlg_accel_group;
+        GClosure *closure;
 
         dlg = GGV_PREFS_DIALOG(g_object_new(GGV_TYPE_PREFS_DIALOG, NULL));
         widget = GTK_WIDGET(dlg);
@@ -308,11 +323,19 @@ ggv_prefs_dialog_new()
         gtk_box_pack_start(GTK_BOX(vbox), sep, 0, FALSE, TRUE);
 
         bbox = gtk_hbutton_box_new();
+        gtk_box_set_spacing(GTK_BOX(bbox), 4);
         gtk_button_box_set_layout(GTK_BUTTON_BOX(bbox), GTK_BUTTONBOX_END);
         gtk_widget_show(bbox);
         gtk_box_pack_end(GTK_BOX(vbox), bbox, 0, FALSE, FALSE);
         
         dlg->cancel = gtk_button_new_from_stock(GTK_STOCK_CANCEL);
+
+        dlg_accel_group = gtk_accel_group_new();
+        closure = g_cclosure_new(G_CALLBACK(ggv_prefs_escape_pressed),
+                                 dlg, NULL);
+        gtk_accel_group_connect(dlg_accel_group, GDK_Escape, 0, 0, closure);
+        gtk_window_add_accel_group(GTK_WINDOW(dlg), dlg_accel_group);
+
         GTK_WIDGET_SET_FLAGS(dlg->cancel, GTK_CAN_DEFAULT);
         gtk_widget_show(dlg->cancel);
         g_signal_connect(G_OBJECT(dlg->cancel), "clicked",
@@ -343,7 +366,7 @@ ggv_prefs_dialog_new()
         table = gtk_table_new(2, 10, FALSE);
 
         /* zoom choice menu */
-        label = gtk_label_new(_("Default Zoom"));
+        label = gtk_label_new(_("Default Zoom:"));
         gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
         gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_RIGHT);
 
@@ -377,7 +400,7 @@ ggv_prefs_dialog_new()
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
 
         /* units choice menu */
-        label = gtk_label_new(_("Coordinate units"));
+        label = gtk_label_new(_("Coordinate units:"));
         gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
         gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_RIGHT);
 
@@ -408,7 +431,7 @@ ggv_prefs_dialog_new()
                          GNOME_PAD_SMALL, GNOME_PAD_SMALL);
 
         /* size choice menu */
-        label = gtk_label_new(_("Fallback page size"));
+        label = gtk_label_new(_("Fallback page size:"));
         gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
         gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_LEFT);
         gtk_table_attach(GTK_TABLE(table), label,
@@ -449,7 +472,7 @@ ggv_prefs_dialog_new()
         gtk_widget_show(dlg->override_size);
 
         /* orientation choice menu */
-        label = gtk_label_new(_("Fallback media orientation"));
+        label = gtk_label_new(_("Fallback media orientation:"));
         gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_LEFT);
         gtk_table_attach(GTK_TABLE(table), label,
                          0, 1, 4, 5,
@@ -626,7 +649,7 @@ ggv_prefs_dialog_new()
                          G_CALLBACK(prefs_dlg_change_handler), dlg);
         gtk_widget_show(dlg->savegeo);
         /* auto jump to beginning of page */
-        dlg->auto_jump= gtk_check_button_new_with_label(_("Jump to beginning of page when using keyboard"));
+        dlg->auto_jump= gtk_check_button_new_with_label(_("Jump to beginning of page"));
         gtk_table_attach(GTK_TABLE(table), dlg->auto_jump,
                          0, 1, 7, 8,
                          GTK_EXPAND | GTK_SHRINK | GTK_FILL,
@@ -645,7 +668,7 @@ ggv_prefs_dialog_new()
         table = gtk_table_new(2, 4, FALSE);
 
         /* interpreter */
-        label = gtk_label_new(_("Interpreter"));
+        label = gtk_label_new(_("Interpreter:"));
         gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
         gtk_table_attach(GTK_TABLE(table), label,
                          0, 1, 0, 1,
@@ -665,7 +688,7 @@ ggv_prefs_dialog_new()
                          G_CALLBACK(prefs_dlg_change_handler), dlg);
         gtk_widget_show(dlg->gs);
         /* interpreter */
-        label = gtk_label_new(_("Antialiasing"));
+        label = gtk_label_new(_("Antialiasing:"));
         gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
         gtk_table_attach(GTK_TABLE(table), label,
                          0, 1, 1, 2,
@@ -685,7 +708,7 @@ ggv_prefs_dialog_new()
                          G_CALLBACK(prefs_dlg_change_handler), dlg);
         gtk_widget_show(dlg->alpha_params);
         /* scan PDF command */
-        label = gtk_label_new(_("Scan PDF"));
+        label = gtk_label_new(_("Scan PDF:"));
         gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
         gtk_table_attach(GTK_TABLE(table), label,
                          0, 1, 2, 3,
@@ -706,7 +729,7 @@ ggv_prefs_dialog_new()
         gtk_widget_show(dlg->scan_pdf);
 
 	/* unzip command: gzip */
-        label = gtk_label_new(_("Gzip"));
+        label = gtk_label_new(_("Gzip:"));
         gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
         gtk_table_attach(GTK_TABLE(table), label,
                          0, 1, 3, 4,
@@ -727,7 +750,7 @@ ggv_prefs_dialog_new()
 	gtk_widget_show(dlg->unzip);
 
 	/* unzip command: bzip2 */
-        label = gtk_label_new(_("Bzip2"));
+        label = gtk_label_new(_("Bzip2:"));
         gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
         gtk_table_attach(GTK_TABLE(table), label,
                          0, 1, 4, 5,
@@ -756,7 +779,7 @@ ggv_prefs_dialog_new()
         table = gtk_table_new(1, 2, FALSE);
 
         /* print command */
-        label = gtk_label_new(_("Print command"));
+        label = gtk_label_new(_("Print command:"));
         gtk_table_attach(GTK_TABLE(table), label,
                          0, 1, 0, 1,
                          GTK_FILL,
